@@ -1,7 +1,7 @@
-export CONDA_EXE='C:\bld\conda_1565126524171\_h_env\Scripts\conda.exe'
+export CONDA_EXE='D:\bld\conda_1574961913256\_h_env\Scripts\conda.exe'
 export _CE_M=''
 export _CE_CONDA=''
-export CONDA_PYTHON_EXE='C:\bld\conda_1565126524171\_h_env\python.exe'
+export CONDA_PYTHON_EXE='D:\bld\conda_1574961913256\_h_env\python.exe'
 
 # Copyright (C) 2012 Anaconda, Inc
 # SPDX-License-Identifier: BSD-3-Clause
