@@ -272,6 +272,8 @@ class Context(Configuration):
 
     target_prefix_override = PrimitiveParameter('')
 
+    unsatisfiable_hints = PrimitiveParameter(True)
+
     # conda_build
     bld_path = PrimitiveParameter('')
     anaconda_upload = PrimitiveParameter(None, aliases=('binstar_upload',),
@@ -845,6 +847,7 @@ class Context(Configuration):
             'report_errors',
             'show_channel_urls',
             'verbosity',
+            'unsatisfiable_hints'
         )),
         ('CLI-only', (
             'deps_modifier',
@@ -1223,6 +1226,10 @@ class Context(Configuration):
                 'local' channel in the list. If the list is empty or left undefined, no
                 channel exclusions will be enforced.
                 """),
+            'unsatisfiable_hints': dals("""
+                A boolean to determine if conda should find conflicting packages in the case
+                of a failed install.
+                """),
 
         })
 
