@@ -13,7 +13,7 @@ from .._vendor.boltons.setutils import IndexedSet
 from .._vendor.toolz import concat, concatv
 from ..base.context import context
 from ..common.compat import itervalues
-from ..common.io import ThreadLimitedThreadPoolExecutor, as_completed, time_recorder
+from ..common.io import ThreadLimitedThreadPoolExecutor, time_recorder
 from ..exceptions import ChannelNotAllowed, InvalidSpec
 from ..gateways.logging import initialize_logging
 from ..models.channel import Channel, all_channel_urls
@@ -74,10 +74,9 @@ def fetch_index(channel_urls, use_cache=False, index=None, repodata_fn=context.r
     log.debug('channel_urls=' + repr(channel_urls))
     index = {}
     with ThreadLimitedThreadPoolExecutor() as executor:
-        futures = tuple(executor.submit(SubdirData, Channel(url), repodata_fn=repodata_fn)
-                        for url in channel_urls)
-        for sd in (future.result() for future in as_completed(futures)):
-            index.update((rec, rec) for rec in sd.iter_records())
+        subdir_instantiator = lambda url: SubdirData(Channel(url), repodata_fn=repodata_fn)
+        for f in executor.map(subdir_instantiator, channel_urls):
+            index.update((rec, rec) for rec in f.iter_records())
     return index
 
 
@@ -91,14 +90,26 @@ def _supplement_index_with_prefix(index, prefix):
     assert prefix
     for prefix_record in PrefixData(prefix).iter_records():
         if prefix_record in index:
-            # The downloaded repodata takes priority, so we do not overwrite.
-            # We do, however, copy the link information so that the solver (i.e. resolve)
-            # knows this package is installed.
             current_record = index[prefix_record]
-            link = prefix_record.get('link') or EMPTY_LINK
-            index[prefix_record] = PrefixRecord.from_objects(
-                current_record, prefix_record, link=link
-            )
+            if current_record.channel == prefix_record.channel:
+                # The downloaded repodata takes priority, so we do not overwrite.
+                # We do, however, copy the link information so that the solver (i.e. resolve)
+                # knows this package is installed.
+                link = prefix_record.get('link') or EMPTY_LINK
+                index[prefix_record] = PrefixRecord.from_objects(
+                    current_record, prefix_record, link=link
+                )
+            else:
+                # If the local packages channel information does not agree with
+                # the channel information in the index then they are most
+                # likely referring to different packages.  This can occur if a
+                # multi-channel changes configuration, e.g. defaults with and
+                # without the free channel. In this case we need to fake the
+                # channel data for the existing package.
+                prefix_channel = prefix_record.channel
+                prefix_channel._Channel__canonical_name = prefix_channel.url()
+                del prefix_record._PackageRecord__pkey
+                index[prefix_record] = prefix_record
         else:
             # If the package is not in the repodata, use the local data.
             # If the channel is known but the package is not in the index, it
@@ -144,7 +155,7 @@ def _supplement_index_with_system(index):
     cuda_version = context.cuda_version
     if cuda_version is not None:
         rec = _make_virtual_package('__cuda', cuda_version)
-        index[rec.name] = rec
+        index[rec] = rec
 
 
 def calculate_channel_urls(channel_urls=(), prepend=True, platform=None, use_local=False):
