@@ -12,8 +12,6 @@ from os.path import basename, dirname, getsize, join
 from sys import platform
 from tarfile import ReadError
 
-from conda_package_handling.api import InvalidArchiveError
-
 from .path_actions import CacheUrlAction, ExtractPackageAction
 from .. import CondaError, CondaMultiError, conda_signal_handler
 from .._vendor.auxlib.collection import first
@@ -291,6 +289,9 @@ class PackageCacheData(object):
         return "%s(%s)" % (self.__class__.__name__, ', '.join(args))
 
     def _make_single_record(self, package_filename):
+        # delay-load this to help make sure libarchive can be found
+        from conda_package_handling.api import InvalidArchiveError
+
         package_tarball_full_path = join(self.pkgs_dir, package_filename)
         log.trace("adding to package cache %s", package_tarball_full_path)
         extracted_package_dir, pkg_ext = strip_pkg_extension(package_tarball_full_path)
@@ -345,9 +346,6 @@ class PackageCacheData(object):
                                 # see https://github.com/conda/conda/issues/6707
                                 rm_rf(package_tarball_full_path)
                                 rm_rf(extracted_package_dir)
-                                log.warn("Encountered corrupt package tarball at %s. Conda has "
-                                         "removed it, but you need to re-run conda to download "
-                                         "it again." % package_tarball_full_path)
                                 return None
                         try:
                             raw_json_record = read_index_json(extracted_package_dir)
@@ -356,9 +354,6 @@ class PackageCacheData(object):
                             # Remove everything and move on.
                             rm_rf(package_tarball_full_path)
                             rm_rf(extracted_package_dir)
-                            log.warn("Encountered corrupt package tarball at %s. Conda has "
-                                     "removed it, but you need to re-run conda to download "
-                                     "it again." % package_tarball_full_path)
                             return None
                     else:
                         raw_json_record = read_index_json_from_tarball(package_tarball_full_path)
@@ -501,14 +496,13 @@ class ProgressiveFetchExtract(object):
                 matches = pcrec.md5 in (md5, legacy_bz2_md5)
             return matches
 
-        if md5:
-            extracted_pcrec = next((
-                pcrec for pcrec in concat(PackageCacheData(pkgs_dir).query(pref_or_spec)
-                                          for pkgs_dir in context.pkgs_dirs)
-                if pcrec.is_extracted
-            ), None)
-            if extracted_pcrec and pcrec_matches(extracted_pcrec) and extracted_pcrec.get('url'):
-                return None, None
+        extracted_pcrec = next((
+            pcrec for pcrec in concat(PackageCacheData(pkgs_dir).query(pref_or_spec)
+                                      for pkgs_dir in context.pkgs_dirs)
+            if pcrec.is_extracted
+        ), None)
+        if extracted_pcrec and pcrec_matches(extracted_pcrec) and extracted_pcrec.get('url'):
+            return None, None
 
         # there is no extracted dist that can work, so now we look for tarballs that
         #   aren't extracted
@@ -634,7 +628,7 @@ class ProgressiveFetchExtract(object):
 
         assert not context.dry_run
 
-        if not self.cache_actions or not self.extract_actions:
+        if not self.cache_actions and not self.extract_actions:
             return
 
         if not context.verbosity and not context.quiet and not context.json:
