@@ -387,7 +387,7 @@ class CondaOSError(CondaError, OSError):
 
 
 class ProxyError(CondaError):
-    def __init__(self, message):
+    def __init__(self):
         message = dals("""
         Conda cannot proceed due to an error in your proxy configuration.
         Check for typos and other configuration errors in any '.netrc' file in your home directory,
@@ -652,13 +652,17 @@ class UnsatisfiableError(CondaError):
         messages = {'python': dals('''
 
 The following specifications were found
-to be incompatible with the existing python installation in your environment:\n{specs}
+to be incompatible with the existing python installation in your environment:
+
+Specifications:\n{specs}
+
+Your python: {ref}
 
 If python is on the left-most side of the chain, that's the version you've asked for.
 When python appears to the right, that indicates that the thing on the left is somehow
-not available for the python version you are constrained to.  Your current python version
-is ({ref}).  Note that conda will not change your python version to a different minor version
-unless you explicitly specify that.
+not available for the python version you are constrained to. Note that conda will not
+change your python version to a different minor version unless you explicitly specify
+that.
 
         '''),
                     'request_conflict_with_history': dals('''
@@ -680,33 +684,41 @@ Your installed CUDA driver is: {ref}
 ''')}
 
         msg = ""
-        for class_name, dep_class in bad_deps.items():
-            if dep_class:
-                _chains = []
-                if class_name == "direct":
-                    msg += messages["direct"]
-                    last_dep_entry = set(d[0][-1].name for d in dep_class)
-                    dep_constraint_map = {}
-                    for dep in dep_class:
-                        if dep[0][-1].name in last_dep_entry:
-                            if not dep_constraint_map.get(dep[0][-1].name):
-                                dep_constraint_map[dep[0][-1].name] = []
-                            dep_constraint_map[dep[0][-1].name].append(dep[0])
-                    for dep, chain in dep_constraint_map.items():
-                        msg += "\nPackage %s conflicts for:\n" % dep
-                        msg += "\n".join([" -> ".join([str(i) for i in c]) for c in chain])
-                else:
-                    for dep_chain, installed_blocker in dep_class:
-                        # Remove any target values from the MatchSpecs, convert to strings
-                        dep_chain = [str(MatchSpec(dep, target=None)) for dep in dep_chain]
-                        _chains.append(dep_chain)
+        if len(bad_deps) == 0:
+            msg += '''
+Did not find conflicting dependencies. If you would like to know which
+packages conflict ensure that you have enabled unsatisfiable hints.
 
-                    if _chains:
-                        _chains = self._format_chain_str(_chains)
+conda config --set unsatisfiable_hints True
+            '''
+        else:
+            for class_name, dep_class in bad_deps.items():
+                if dep_class:
+                    _chains = []
+                    if class_name == "direct":
+                        msg += messages["direct"]
+                        last_dep_entry = set(d[0][-1].name for d in dep_class)
+                        dep_constraint_map = {}
+                        for dep in dep_class:
+                            if dep[0][-1].name in last_dep_entry:
+                                if not dep_constraint_map.get(dep[0][-1].name):
+                                    dep_constraint_map[dep[0][-1].name] = []
+                                dep_constraint_map[dep[0][-1].name].append(dep[0])
+                        for dep, chain in dep_constraint_map.items():
+                            msg += "\nPackage %s conflicts for:\n" % dep
+                            msg += "\n".join([" -> ".join([str(i) for i in c]) for c in chain])
                     else:
-                        _chains = [', '.join(c) for c in _chains]
-                    msg += messages[class_name].format(specs=dashlist(_chains),
-                                                       ref=installed_blocker)
+                        for dep_chain, installed_blocker in dep_class:
+                            # Remove any target values from the MatchSpecs, convert to strings
+                            dep_chain = [str(MatchSpec(dep, target=None)) for dep in dep_chain]
+                            _chains.append(dep_chain)
+
+                        if _chains:
+                            _chains = self._format_chain_str(_chains)
+                        else:
+                            _chains = [', '.join(c) for c in _chains]
+                        msg += messages[class_name].format(specs=dashlist(_chains),
+                                                           ref=installed_blocker)
         if strict:
             msg += ('\nNote that strict channel priority may have removed '
                     'packages required for satisfiability.')
