@@ -22,7 +22,7 @@ try:
     from requests.adapters import BaseAdapter, HTTPAdapter
     from requests.auth import AuthBase, _basic_auth_str
     from requests.cookies import extract_cookies_to_jar
-    from requests.exceptions import InvalidSchema, SSLError
+    from requests.exceptions import InvalidSchema, SSLError, ProxyError as RequestsProxyError
     from requests.hooks import dispatch_hook
     from requests.models import Response
     from requests.packages.urllib3.exceptions import InsecureRequestWarning
@@ -39,7 +39,8 @@ except ImportError:  # pragma: no cover
     from pip._vendor.requests.adapters import BaseAdapter, HTTPAdapter
     from pip._vendor.requests.auth import AuthBase, _basic_auth_str
     from pip._vendor.requests.cookies import extract_cookies_to_jar
-    from pip._vendor.requests.exceptions import InvalidSchema, SSLError
+    from pip._vendor.requests.exceptions import (InvalidSchema, SSLError,
+                                                 ProxyError as RequestsProxyError)
     from pip._vendor.requests.hooks import dispatch_hook
     from pip._vendor.requests.models import Response
     from pip._vendor.requests.packages.urllib3.exceptions import InsecureRequestWarning
@@ -69,3 +70,4 @@ HTTPError = HTTPError
 InvalidSchema = InvalidSchema
 SSLError = SSLError
 InsecureRequestWarning = InsecureRequestWarning
+RequestsProxyError = RequestsProxyError
