@@ -332,10 +332,13 @@ class Resolve(object):
         return tuple(f for f in matches if f.channel.name == sole_source_channel_name)
 
     def find_conflicts(self, specs, specs_to_add=None, history_specs=None):
-        if not context.json:
-            print("\nFound conflicts! Looking for incompatible packages.\n"
-                  "This can take several minutes.  Press CTRL-C to abort.")
-        bad_deps = self.build_conflict_map(specs, specs_to_add, history_specs)
+        if context.unsatisfiable_hints:
+            if not context.json:
+                print("\nFound conflicts! Looking for incompatible packages.\n"
+                      "This can take several minutes.  Press CTRL-C to abort.")
+            bad_deps = self.build_conflict_map(specs, specs_to_add, history_specs)
+        else:
+            bad_deps = {}
         strict_channel_priority = context.channel_priority == ChannelPriority.STRICT
         raise UnsatisfiableError(bad_deps, strict=strict_channel_priority)
 
@@ -1047,16 +1050,22 @@ class Resolve(object):
         if not specs:
             return ()
 
+        all_specs = set(specs) | set(explicit_specs)
+        reduced_index = self.get_reduced_index(all_specs)
+
         # Check if satisfiable
         def mysat(specs, add_if=False):
             constraints = r2.generate_spec_constraints(C, specs)
             return C.sat(constraints, add_if)
 
-        r2 = Resolve(self.index, True, channels=self.channels)
+        r2 = Resolve(reduced_index, True, channels=self.channels)
         C = r2.gen_clauses()
-        solution = mysat((set(specs) | set(explicit_specs)), True)
+        solution = mysat(all_specs, True)
         final_unsat_specs = ()
+
         if not solution:
+            r2 = Resolve(self.index, True, channels=self.channels)
+            C = r2.gen_clauses()
             # This first result is just a single unsatisfiable core. There may be several.
             final_unsat_specs = minimal_unsatisfiable_subset(specs, sat=mysat,
                                                              explicit_specs=explicit_specs)
