@@ -6,6 +6,11 @@ from __future__ import absolute_import, division, print_function
 import os
 import sys
 
+# pip_util.py import on_win from conda.exports
+# conda.exports resets the context
+# we need to import conda.exports here so that the context is not lost
+# when importing pip (and pip_util)
+import conda.exports  # noqa
 from conda.base.context import context
 from conda.cli.conda_argparse import ArgumentParser
 from conda.cli.main import init_loggers
