@@ -366,15 +366,16 @@ class ActivatorUnitTests(TestCase):
                         'PS1': '(/old/prefix)',
                     }
                     export_vars = OrderedDict((
-                        ('PATH', old_path),
                         ('CONDA_PREFIX', old_prefix),
                         ('CONDA_SHLVL', 1),
                         ('CONDA_DEFAULT_ENV', old_prefix),
                         ('CONDA_PROMPT_MODIFIER', '(%s)' % old_prefix),
                     ))
+                    export_path = {'PATH': old_path,}
                     export_vars, unset_vars = activator.add_export_unset_vars(export_vars, unset_vars)
                     assert builder['unset_vars'] == unset_vars
                     assert builder['export_vars'] == export_vars
+                    assert builder['export_path'] == export_path
                     assert builder['activate_scripts'] == ()
                     assert builder['deactivate_scripts'] == ()
 
@@ -447,12 +448,12 @@ class ActivatorUnitTests(TestCase):
                         'PS1': '(/old/prefix)',
                     }
                     export_vars = OrderedDict((
-                        ('PATH', old_path),
                         ('CONDA_PREFIX', old_prefix),
                         ('CONDA_SHLVL', 1),
                         ('CONDA_DEFAULT_ENV', old_prefix),
                         ('CONDA_PROMPT_MODIFIER', '(%s)' % old_prefix)
                     ))
+                    export_path = {'PATH': old_path,}
                     export_vars, unset_vars = activator.add_export_unset_vars(export_vars, unset_vars)
                     assert builder['unset_vars'] == unset_vars
                     assert builder['export_vars'] == export_vars
@@ -544,16 +545,17 @@ class ActivatorUnitTests(TestCase):
                         'PS1': ps1,
                     }
                     export_vars = OrderedDict((
-                        ('PATH', original_path),
                         ('CONDA_PREFIX', old_prefix),
                         ('CONDA_SHLVL', 1),
                         ('CONDA_DEFAULT_ENV', old_prefix),
                         ('CONDA_PROMPT_MODIFIER', conda_prompt_modifier),
                     ))
+                    export_path = {'PATH': original_path,}
                     export_vars, unset_vars = activator.add_export_unset_vars(export_vars, unset_vars)
                     assert builder['unset_vars'] == unset_vars
                     assert builder['set_vars'] == set_vars
                     assert builder['export_vars'] == export_vars
+                    assert builder['export_path'] == export_path
                     assert builder['activate_scripts'] == (activator.path_conversion(activate_d_1),)
                     assert builder['deactivate_scripts'] == (activator.path_conversion(deactivate_d_1),)
 
@@ -595,16 +597,17 @@ class ActivatorUnitTests(TestCase):
                     'PS1': ps1,
                 }
                 export_vars = OrderedDict((
-                    ('PATH', original_path),
                     ('CONDA_PREFIX', old_prefix),
                     ('CONDA_SHLVL', 1),
                     ('CONDA_DEFAULT_ENV', old_prefix),
                     ('CONDA_PROMPT_MODIFIER', conda_prompt_modifier),
                 ))
+                export_path = {'PATH': original_path,}
                 export_vars, unset_vars = activator.add_export_unset_vars(export_vars, unset_vars)
                 assert builder['unset_vars'] == unset_vars
                 assert builder['set_vars'] == set_vars
                 assert builder['export_vars'] == export_vars
+                assert builder['export_path'] == export_path
                 assert builder['activate_scripts'] == (activator.path_conversion(activate_d_1),)
                 assert builder['deactivate_scripts'] == (activator.path_conversion(deactivate_d_1),)
 
@@ -634,13 +637,14 @@ class ActivatorUnitTests(TestCase):
                         'PS1': os.environ.get('PS1', ''),
                     }
                     export_vars = OrderedDict((
-                        ('PATH', new_path),
                         ('CONDA_SHLVL', 0),
                     ))
+                    export_path = {'PATH': new_path,}
                     export_vars, unset_vars = activator.add_export_unset_vars(export_vars, unset_vars,
                                                                               conda_exe_vars=True)
                     assert builder['export_vars'] == export_vars
                     assert builder['unset_vars'] == unset_vars
+                    assert builder['export_path'] == export_path
                     assert builder['activate_scripts'] == ()
                     assert builder['deactivate_scripts'] == (activator.path_conversion(deactivate_d_1),)
 
@@ -770,13 +774,13 @@ class ShellWrapperUnitTests(TestCase):
             conda_exe_export, conda_exe_unset = activator.get_scripts_export_unset_vars(conda_exe_vars=True)
 
             e_deactivate_data = dals("""
+            export PATH='%(new_path)s'
             . "%(deactivate1)s"
             %(conda_exe_unset)s
             unset CONDA_PREFIX
             unset CONDA_DEFAULT_ENV
             unset CONDA_PROMPT_MODIFIER
             PS1='%(ps1)s'
-            export PATH='%(new_path)s'
             export CONDA_SHLVL='0'
             %(conda_exe_export)s
             """) % {
@@ -866,11 +870,11 @@ class ShellWrapperUnitTests(TestCase):
 
             new_path = activator.pathsep_join(activator._remove_prefix_from_path(self.prefix))
             e_deactivate_data = dals("""
+            @SET "PATH=%(new_path)s"
             @CALL "%(deactivate1)s"
             @SET CONDA_PREFIX=
             @SET CONDA_DEFAULT_ENV=
             @SET CONDA_PROMPT_MODIFIER=
-            @SET "PATH=%(new_path)s"
             @SET "CONDA_SHLVL=0"
             %(conda_exe_export)s
             """) % {
@@ -953,12 +957,12 @@ class ShellWrapperUnitTests(TestCase):
             conda_exe_export, conda_exe_unset = activator.get_scripts_export_unset_vars(conda_exe_vars=True)
 
             e_deactivate_data = dals("""
+            setenv PATH "%(new_path)s";
             source "%(deactivate1)s";
             unsetenv CONDA_PREFIX;
             unsetenv CONDA_DEFAULT_ENV;
             unsetenv CONDA_PROMPT_MODIFIER;
             set prompt='%(prompt)s';
-            setenv PATH "%(new_path)s";
             setenv CONDA_SHLVL "0";
             %(conda_exe_export)s;
             """) % {
@@ -977,11 +981,7 @@ class ShellWrapperUnitTests(TestCase):
             rc = activate_main(['', 'shell.xonsh'] + activate_args + [self.prefix])
         assert not c.stderr
         assert rc == 0
-        activate_result = c.stdout
-
-        with open(activate_result) as fh:
-            activate_data = fh.read()
-        rm_rf(activate_result)
+        activate_data = c.stdout
 
         new_path_parts = activator._add_prefix_to_path(self.prefix)
         conda_exe_export, conda_exe_unset = activator.get_scripts_export_unset_vars()
@@ -1010,13 +1010,10 @@ class ShellWrapperUnitTests(TestCase):
         }):
             activator = XonshActivator()
             with captured() as c:
-                assert activate_main(['', 'shell.xonsh'] + reactivate_args) == 0
+                rc = activate_main(['', 'shell.xonsh'] + reactivate_args)
             assert not c.stderr
-            reactivate_result = c.stdout
-
-            with open(reactivate_result) as fh:
-                reactivate_data = fh.read()
-            rm_rf(reactivate_result)
+            assert rc == 0
+            reactivate_data = c.stdout
 
             new_path_parts = activator._replace_prefix_in_path(self.prefix, self.prefix)
             e_reactivate_data = dals("""
@@ -1026,29 +1023,27 @@ class ShellWrapperUnitTests(TestCase):
             $CONDA_PROMPT_MODIFIER = '(%(native_prefix)s) '
             source "%(activate1)s"
             """) % {
+                'new_path': activator.pathsep_join(new_path_parts),
                 'activate1': activator.path_conversion(join(self.prefix, 'etc', 'conda', 'activate.d', 'activate1.xsh')),
                 'deactivate1': activator.path_conversion(join(self.prefix, 'etc', 'conda', 'deactivate.d', 'deactivate1.xsh')),
                 'native_prefix': self.prefix,
-                'new_path': activator.pathsep_join(new_path_parts),
             }
             assert reactivate_data == e_reactivate_data
 
             with captured() as c:
-                assert activate_main(['', 'shell.xonsh'] + deactivate_args) == 0
+                rc = activate_main(['', 'shell.xonsh'] + deactivate_args)
             assert not c.stderr
-            deactivate_result = c.stdout
-
-            with open(deactivate_result) as fh:
-                deactivate_data = fh.read()
-            rm_rf(deactivate_result)
+            assert rc == 0
+            deactivate_data = c.stdout
 
             new_path = activator.pathsep_join(activator._remove_prefix_from_path(self.prefix))
+            conda_exe_export, conda_exe_unset = activator.get_scripts_export_unset_vars()
             e_deactivate_data = dals("""
+            $PATH = '%(new_path)s'
             source "%(deactivate1)s"
             del $CONDA_PREFIX
             del $CONDA_DEFAULT_ENV
             del $CONDA_PROMPT_MODIFIER
-            $PATH = '%(new_path)s'
             $CONDA_SHLVL = '0'
             %(conda_exe_export)s
             """) % {
@@ -1124,11 +1119,11 @@ class ShellWrapperUnitTests(TestCase):
             new_path = activator.pathsep_join(activator._remove_prefix_from_path(self.prefix))
             conda_exe_export, conda_exe_unset = activator.get_scripts_export_unset_vars()
             e_deactivate_data = dals("""
+            set -gx PATH "%(new_path)s";
             source "%(deactivate1)s";
             set -e CONDA_PREFIX;
             set -e CONDA_DEFAULT_ENV;
             set -e CONDA_PROMPT_MODIFIER;
-            set -gx PATH "%(new_path)s";
             set -gx CONDA_SHLVL "0";
             %(conda_exe_export)s;
             """) % {
@@ -1200,12 +1195,13 @@ class ShellWrapperUnitTests(TestCase):
             deactivate_data = c.stdout
 
             new_path = activator.pathsep_join(activator._remove_prefix_from_path(self.prefix))
+
             assert deactivate_data == dals("""
+            $Env:PATH = "%(new_path)s"
             . "%(deactivate1)s"
             Remove-Item Env:/CONDA_PREFIX
             Remove-Item Env:/CONDA_DEFAULT_ENV
             Remove-Item Env:/CONDA_PROMPT_MODIFIER
-            $Env:PATH = "%(new_path)s"
             $Env:CONDA_SHLVL = "0"
             %(conda_exe_export)s
             """) % {
@@ -2027,3 +2023,45 @@ class ShellWrapperIntegrationTests(TestCase):
             shell.sendline("deactivate --dev")
             conda_shlvl = shell.get_env_var('CONDA_SHLVL')
             assert conda_shlvl == '0', conda_shlvl
+
+@pytest.mark.integration
+class ActivationIntegrationTests(TestCase):
+
+    def setUp(self):
+        tempdirdir = gettempdir()
+
+        prefix_dirname = str(uuid4())[:4] + SPACER_CHARACTER + str(uuid4())[:4]
+        self.prefix = join(tempdirdir, prefix_dirname)
+        mkdir_p(join(self.prefix, 'conda-meta'))
+        assert isdir(self.prefix)
+        touch(join(self.prefix, 'conda-meta', 'history'))
+
+        self.prefix2 = join(self.prefix, 'envs', 'charizard')
+        mkdir_p(join(self.prefix2, 'conda-meta'))
+        touch(join(self.prefix2, 'conda-meta', 'history'))
+
+    def tearDown(self):
+        rm_rf(self.prefix)
+        rm_rf(self.prefix2)
+
+    def activate_deactivate_modify_path(self, shell):
+        activate_deactivate_package = "activate_deactivate_package"
+        activate_deactivate_package_path_string = "teststringfromactivate/bin/test"
+        original_path = os.environ.get("PATH")
+        run_command(Commands.INSTALL, self.prefix2, activate_deactivate_package, "-c", "c3i_test2")
+
+        with InteractiveShell(shell) as shell:
+            shell.sendline('conda activate "%s"' % self.prefix2)
+            activated_env_path = shell.get_env_var("PATH")
+            shell.sendline('conda deactivate')
+
+        assert activate_deactivate_package_path_string in activated_env_path
+        assert original_path == os.environ.get("PATH")
+
+    @pytest.mark.skipif(bash_unsupported(), reason=bash_unsupported_because())
+    def test_activate_deactivate_modify_path_bash(self):
+        self.activate_deactivate_modify_path("bash")
+
+    @pytest.mark.skipif(not which('cmd.exe'), reason='cmd.exe not installed')
+    def test_activate_deactivate_modify_path(self):
+        self.activate_deactivate_modify_path("cmd.exe")
